import { jsx, Fragment } from 'react/jsx-runtime';
import { useCallback } from 'react';
import { EditorFieldGroup, EditorField } from '@grafana/experimental';
import { InlineFieldRow, InlineField, Combobox } from '@grafana/ui';
import { regexifyLabelValuesQueryString } from '../parsingUtils.js';

function MetricCombobox({
  datasource,
  query,
  onChange,
  onGetMetrics,
  labelsFilters,
  variableEditor
}) {
  const getMetricLabels = useCallback(
    async (query2) => {
      const results = await datasource.metricFindQuery(formatKeyValueStringsForLabelValuesQuery(query2, labelsFilters));
      const resultsOptions = results.map((result) => {
        return {
          label: result.text,
          value: result.text
        };
      });
      return resultsOptions;
    },
    [datasource, labelsFilters]
  );
  const onComboboxChange = useCallback(
    (opt) => {
      var _a;
      onChange({ ...query, metric: (_a = opt == null ? void 0 : opt.value) != null ? _a : "" });
    },
    [onChange, query]
  );
  const loadOptions = useCallback(
    async (input) => {
      const metrics = input.length ? await getMetricLabels(input) : await onGetMetrics();
      return metrics.map((option) => {
        var _a;
        return {
          label: (_a = option.label) != null ? _a : option.value,
          value: option.value
        };
      });
    },
    [getMetricLabels, onGetMetrics]
  );
  const asyncSelect = () => {
    return /* @__PURE__ */ jsx(
      Combobox,
      {
        placeholder: "Select metric",
        width: "auto",
        minWidth: 25,
        options: loadOptions,
        value: query.metric,
        onChange: onComboboxChange
      }
    );
  };
  return /* @__PURE__ */ jsx(Fragment, { children: variableEditor ? /* @__PURE__ */ jsx(InlineFieldRow, { children: /* @__PURE__ */ jsx(
    InlineField,
    {
      label: "Metric",
      labelWidth: 20,
      tooltip: /* @__PURE__ */ jsx("div", { children: "Optional: returns a list of label values for the label name in the specified metric." }),
      children: asyncSelect()
    }
  ) }) : /* @__PURE__ */ jsx(EditorFieldGroup, { children: /* @__PURE__ */ jsx(EditorField, { label: "Metric", children: asyncSelect() }) }) });
}
const formatPrometheusLabelFiltersToString = (queryString, labelsFilters) => {
  const filterArray = labelsFilters ? formatPrometheusLabelFilters(labelsFilters) : [];
  return `label_values({__name__=~".*${queryString}"${filterArray ? filterArray.join("") : ""}},__name__)`;
};
const formatPrometheusLabelFilters = (labelsFilters) => {
  return labelsFilters.map((label) => {
    return `,${label.label}="${label.value}"`;
  });
};
const formatKeyValueStringsForLabelValuesQuery = (query, labelsFilters) => {
  const queryString = regexifyLabelValuesQueryString(query);
  return formatPrometheusLabelFiltersToString(queryString, labelsFilters);
};

export { MetricCombobox, formatPrometheusLabelFilters, formatPrometheusLabelFiltersToString };
//# sourceMappingURL=MetricCombobox.js.map
